@@ -1,4 +1,4 @@
-"""To be employed with `BddTester` and `BaseTestCase`"""
+"""To be employed with `BddTester`"""
 import collections
 import datetime
 import itertools
@@ -42,7 +42,7 @@ class StepRun(stock.Repr):
 
     @end_time.setter
     def end_time(self, value):
-        raise AttributeError("'end_time' is read-only")
+        raise AssertionError("'end_time' is read-only")
 
     def __str__(self):
         return (f'{self.end_time} {self.symbol} {self.step.method_qualname}'
@@ -121,7 +121,7 @@ class ScenarioRun(stock.Repr):
 
     @end_time.setter
     def end_time(self, value):
-        raise AttributeError("'end_time' is read-only")
+        raise AssertionError("'end_time' is read-only")
 
     def iter_step_runs(self):
         for run in self.runs:
@@ -143,7 +143,7 @@ class ScenarioRun(stock.Repr):
 
 class Step(StepSpec):
     def __init__(self, text, ordinal, scenario):
-        super().__init__(text, ordinal, scenario.gherkin.aliases)
+        super().__init__(text, ordinal)
         self.scenario = scenario
         self.doc_scenario = None
         self.test_scenario = None
@@ -175,6 +175,7 @@ class Step(StepSpec):
             step_run = tester.current_run.get_pending_step_run(self)
             step_run.kwargs = {k: v for k, v in kwargs.items()
                                if k not in self.gherkin.fixtures_not_to_log}
+            tester.param = self.fixture_param[0] if self.inputs else ()
 
             try:
                 step_run.result = step_method(tester, *args, **kwargs)
@@ -304,12 +305,11 @@ class Scenario(stock.Repr):
 
 
 class Gherkin(stock.Repr):
-    def __init__(self, aliases, validate=True, fixtures_not_to_log=('request',),
+    def __init__(self, validate=True, fixtures_not_to_log=('request',),
                  **logging_kwds):
         self.reset_logger(**logging_kwds)
         self.reset_outputs()
         self.scenarios = collections.defaultdict(dict)
-        self.aliases = aliases
         self.validate = validate
         self.fixtures_not_to_log = fixtures_not_to_log
         self.test_runs = {}
@@ -345,13 +345,14 @@ class Gherkin(stock.Repr):
         self.test_runs[test_id] = ScenarioRun(test_id, scenario)
         self.logger.info('_'*26)
 
-    def reset_logger(self, logs_path, maxBytes=100000, backupCount=10):
+    def reset_logger(self, logs_path='./', maxBytes=1000000, backupCount=10):
         self.logger = logging.getLogger('bdd_test_runs')
         self.logger.setLevel(level=logging.INFO)
         handler = RotatingFileHandler(logs_path, maxBytes=maxBytes, backupCount=backupCount)
         handler.setFormatter(logging.Formatter('%(message)s'))
         self.logger.handlers.clear()
         self.logger.addHandler(handler)
+        self.logger.propagate = False
 
     def log(self, fail_if_pending=False):
         __tracebackhide__ = True
@@ -370,7 +371,7 @@ class Gherkin(stock.Repr):
                     self.logger.info(indent(str(r)) + '\n')
 
         if runs[PENDING] and fail_if_pending:
-            names = ', '.join(list(runs[FAIL]))
+            names = ', '.join(list(runs[PENDING]))
             pytest.fail(f'These scenarios did not run: {names}')
 
     def get_scenario_runs(self, symbols=(OK, FAIL, PENDING)):
